@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008, Nokia (urho.konttori@nokia.com)
+ * Copyright (C) 2008, Nokia <ivan.frade@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -20,43 +20,28 @@
 #ifndef __LIBTRACKER_COMMON_H__
 #define __LIBTRACKER_COMMON_H__
 
-#include <glib.h>
-
-G_BEGIN_DECLS
-
-#if !defined (TRACKER_ENABLE_INTERNALS) && !defined (TRACKER_COMPILATION)
-#error "TRACKER_ENABLE_INTERNALS not defined, this must be defined to use tracker's internal functions"
+#if !defined (__LIBTRACKER_COMMON_INSIDE__) && !defined (TRACKER_COMPILATION)
+#error "only <libtracker-common/tracker-common.h> must be included directly."
 #endif
 
+#include <glib.h>
+
 #define __LIBTRACKER_COMMON_INSIDE__
 
-/* Not installed headers */
-#if 0
-#include "tracker-dbus.h"
-#include "tracker-ioprio.h"
-#include "tracker-log.h"
-#include "tracker-os-dependant.h"
-#include "tracker-power.h"
-#include "tracker-storage.h"
-#endif
-
-/* Installed headers */
-#include "tracker-class.h"
 #include "tracker-config-file.h"
 #include "tracker-date-time.h"
+#include "tracker-dbus.h"
 #include "tracker-file-utils.h"
+#include "tracker-ioprio.h"
 #include "tracker-keyfile-object.h"
 #include "tracker-language.h"
-#include "tracker-namespace.h"
-#include "tracker-ontology.h"
+#include "tracker-log.h"
 #include "tracker-ontologies.h"
-#include "tracker-property.h"
+#include "tracker-os-dependant.h"
+#include "tracker-power.h"
 #include "tracker-type-utils.h"
 #include "tracker-utils.h"
 
 #undef __LIBTRACKER_COMMON_INSIDE__
 
-
-G_END_DECLS
-
 #endif /* __LIBTRACKER_COMMON_H__ */
