@@ -538,31 +538,58 @@ extract_jpeg (const gchar          *uri,
 	if (md.city || md.state || md.address || md.country) {
 		tracker_sparql_builder_predicate (metadata, "mlo:location");
 
-		tracker_sparql_builder_object_blank_open (metadata);
+		tracker_sparql_builder_object_blank_open (metadata); /* GeoPoint */
 		tracker_sparql_builder_predicate (metadata, "a");
 		tracker_sparql_builder_object (metadata, "mlo:GeoPoint");
-	
+
 		if (md.address) {
 			tracker_sparql_builder_predicate (metadata, "mlo:address");
 			tracker_sparql_builder_object_unvalidated (metadata, md.address);
 		}
-	
+
 		if (md.state) {
 			tracker_sparql_builder_predicate (metadata, "mlo:state");
 			tracker_sparql_builder_object_unvalidated (metadata, md.state);
 		}
-	
+
 		if (md.city) {
 			tracker_sparql_builder_predicate (metadata, "mlo:city");
 			tracker_sparql_builder_object_unvalidated (metadata, md.city);
 		}
-	
+
 		if (md.country) {
 			tracker_sparql_builder_predicate (metadata, "mlo:country");
 			tracker_sparql_builder_object_unvalidated (metadata, md.country);
 		}
-		
-		tracker_sparql_builder_object_blank_close (metadata);
+
+		tracker_sparql_builder_predicate (metadata, "mlo:asPostalAddress");
+		tracker_sparql_builder_object_blank_open (metadata); /* PostalAddress */
+
+		tracker_sparql_builder_predicate (metadata, "a");
+		tracker_sparql_builder_object (metadata, "nco:PostalAddress");
+
+		if (md.address) {
+			tracker_sparql_builder_predicate (metadata, "nco:streetAddress");
+			tracker_sparql_builder_object_unvalidated (metadata, md.address);
+		}
+
+		if (md.state) {
+			tracker_sparql_builder_predicate (metadata, "nco:region");
+			tracker_sparql_builder_object_unvalidated (metadata, md.state);
+		}
+
+		if (md.city) {
+			tracker_sparql_builder_predicate (metadata, "nco:locality");
+			tracker_sparql_builder_object_unvalidated (metadata, md.city);
+		}
+
+		if (md.country) {
+			tracker_sparql_builder_predicate (metadata, "nco:country");
+			tracker_sparql_builder_object_unvalidated (metadata, md.country);
+		}
+
+		tracker_sparql_builder_object_blank_close (metadata); /* PostalAddress */
+		tracker_sparql_builder_object_blank_close (metadata); /* GeoPoint */
 	}
 
 	if (cinfo.density_unit != 0 || ed->x_resolution) {
