@@ -34,6 +34,8 @@
 #define UNKNOWN_METHOD_MESSAGE "Method \"%s\" with signature \"%s\" on " \
                                "interface \"%s\" doesn't exist, expected \"%s\""
 
+#define TRACKER_SPARQL_DBUS_ERROR "org.freedesktop.Tracker1.SparqlError.Internal"
+
 /**
  * /!\ IMPORTANT WARNING /!\
  *
@@ -107,7 +109,7 @@ query_callback (gpointer  inthread_data,
 		                             &ptr->error,
 		                             NULL);
 		reply = dbus_message_new_error (info->call_message,
-		                                TRACKER_STEROIDS_INTERFACE ".QueryError",
+		                                TRACKER_SPARQL_DBUS_ERROR,
 		                                ptr->error->message);
 		dbus_connection_send (info->connection, reply, NULL);
 		dbus_message_unref (reply);
@@ -119,7 +121,7 @@ query_callback (gpointer  inthread_data,
 		                             &error,
 		                             NULL);
 		reply = dbus_message_new_error (info->call_message,
-		                                TRACKER_STEROIDS_INTERFACE ".QueryError",
+		                                TRACKER_SPARQL_DBUS_ERROR,
 		                                error->message);
 		dbus_connection_send (info->connection, reply, NULL);
 		dbus_message_unref (reply);
@@ -165,7 +167,7 @@ update_callback (GError *error, gpointer user_data)
 		                             &error,
 		                             NULL);
 		reply = dbus_message_new_error (info->call_message,
-		                                TRACKER_STEROIDS_INTERFACE ".UpdateError",
+		                                TRACKER_SPARQL_DBUS_ERROR,
 		                                error->message);
 		dbus_connection_send (info->connection, reply, NULL);
 		dbus_message_unref (reply);
@@ -212,7 +214,7 @@ update_array_callback (GError *error, gpointer user_data)
 			const gchar *message = "";
 
 			if (error) {
-				str = TRACKER_STEROIDS_INTERFACE ".UpdateError";
+				str = TRACKER_SPARQL_DBUS_ERROR;
 				message = error->message;
 			}
 
@@ -280,7 +282,7 @@ update_blank_callback (GPtrArray *blank_nodes,
 		                             &error,
 		                             NULL);
 		reply = dbus_message_new_error (info->call_message,
-		                                TRACKER_STEROIDS_INTERFACE ".UpdateBlankError",
+		                                TRACKER_SPARQL_DBUS_ERROR,
 		                                error->message);
 		dbus_connection_send (info->connection, reply, NULL);
 		dbus_message_unref (reply);
@@ -648,6 +650,7 @@ steroids_update (TrackerSteroids *steroids,
 	data_input_stream = g_data_input_stream_new (input_stream);
 	g_buffered_input_stream_set_buffer_size (G_BUFFERED_INPUT_STREAM (data_input_stream),
 	                                         TRACKER_STEROIDS_BUFFER_SIZE);
+	g_data_input_stream_set_byte_order (data_input_stream, G_DATA_STREAM_BYTE_ORDER_HOST_ENDIAN);
 
 	query_size = g_data_input_stream_read_int32 (data_input_stream,
 	                                             NULL,
@@ -655,7 +658,7 @@ steroids_update (TrackerSteroids *steroids,
 
 	if (error) {
 		reply = dbus_message_new_error (info->call_message,
-		                                TRACKER_STEROIDS_INTERFACE ".UpdateError",
+		                                TRACKER_SPARQL_DBUS_ERROR,
 		                                error->message);
 		dbus_connection_send (connection, reply, NULL);
 		dbus_message_unref (reply);
@@ -685,7 +688,7 @@ steroids_update (TrackerSteroids *steroids,
 
 	if (error) {
 		reply = dbus_message_new_error (info->call_message,
-		                                TRACKER_STEROIDS_INTERFACE ".UpdateError",
+		                                TRACKER_SPARQL_DBUS_ERROR,
 		                                error->message);
 		dbus_connection_send (connection, reply, NULL);
 		dbus_message_unref (reply);
@@ -823,6 +826,7 @@ steroids_update_array (TrackerSteroids *steroids,
 
 	input_stream = g_unix_input_stream_new (info->fd, TRUE);
 	data_input_stream = g_data_input_stream_new (input_stream);
+	g_data_input_stream_set_byte_order (data_input_stream, G_DATA_STREAM_BYTE_ORDER_HOST_ENDIAN);
 	g_buffered_input_stream_set_buffer_size (G_BUFFERED_INPUT_STREAM (data_input_stream),
 	                                         TRACKER_STEROIDS_BUFFER_SIZE);
 
@@ -832,7 +836,7 @@ steroids_update_array (TrackerSteroids *steroids,
 
 	if (error) {
 		reply = dbus_message_new_error (info->call_message,
-		                                TRACKER_STEROIDS_INTERFACE ".UpdateError",
+		                                TRACKER_SPARQL_DBUS_ERROR,
 		                                error->message);
 		dbus_connection_send (connection, reply, NULL);
 		dbus_message_unref (reply);
@@ -863,7 +867,7 @@ steroids_update_array (TrackerSteroids *steroids,
 
 		if (error) {
 			reply = dbus_message_new_error (info->call_message,
-			                                TRACKER_STEROIDS_INTERFACE ".UpdateError",
+			                                TRACKER_SPARQL_DBUS_ERROR,
 			                                error->message);
 			dbus_connection_send (connection, reply, NULL);
 			dbus_message_unref (reply);
@@ -894,7 +898,7 @@ steroids_update_array (TrackerSteroids *steroids,
 
 		if (error) {
 			reply = dbus_message_new_error (info->call_message,
-			                                TRACKER_STEROIDS_INTERFACE ".UpdateError",
+			                                TRACKER_SPARQL_DBUS_ERROR,
 			                                error->message);
 			dbus_connection_send (connection, reply, NULL);
 			dbus_message_unref (reply);
