@@ -42,21 +42,21 @@
 
 #define TRACKER_STORE_MAX_CONCURRENT_QUERIES               2
 
-#define TRACKER_STORE_QUERY_WATCHDOG_TIMEOUT 10
 #define TRACKER_STORE_MAX_TASK_TIME          30
 
 typedef struct {
-	gboolean     start_log;
-	GQueue      *query_queues[TRACKER_STORE_N_PRIORITIES];
-	GQueue      *update_queues[TRACKER_STORE_N_PRIORITIES];
-	guint        n_queries_running;
-	gboolean     update_running;
-	GThreadPool *update_pool;
-	GThreadPool *query_pool;
-	GSList      *running_tasks;
-	guint        watchdog_id;
-	guint        max_task_time;
-	gboolean     active;
+	gboolean       start_log;
+	GQueue        *query_queues[TRACKER_STORE_N_PRIORITIES];
+	GQueue        *update_queues[TRACKER_STORE_N_PRIORITIES];
+	guint          n_queries_running;
+	gboolean       update_running;
+	GThreadPool   *update_pool;
+	GThreadPool   *query_pool;
+	GSList        *running_tasks;
+	guint          max_task_time;
+	gboolean       active;
+	GDestroyNotify active_callback;
+	gpointer       active_user_data;
 } TrackerStorePrivate;
 
 typedef enum {
@@ -72,8 +72,8 @@ typedef struct {
 		struct {
 			gchar        *query;
 			GCancellable *cancellable;
-			GTimer       *timer;
 			gpointer      thread_data;
+			guint         watchdog_id;
 		} query;
 		struct {
 			gchar        *query;
@@ -98,6 +98,11 @@ typedef struct {
 	} callback;
 } TrackerStoreTask;
 
+typedef struct {
+	GDestroyNotify callback;
+	gpointer user_data;
+} SetActiveDelegate;
+
 static GStaticPrivate private_key = G_STATIC_PRIVATE_INIT;
 
 #ifdef __USE_GNU
@@ -125,8 +130,8 @@ store_task_free (TrackerStoreTask *task)
 		g_free (task->data.turtle.path);
 	} else if (task->type == TRACKER_STORE_TASK_TYPE_QUERY) {
 		g_free (task->data.query.query);
-		if (task->data.query.timer) {
-			g_timer_destroy (task->data.query.timer);
+		if (task->data.query.watchdog_id) {
+			g_source_remove (task->data.query.watchdog_id);
 		}
 		if (task->data.query.cancellable) {
 			g_object_unref (task->data.query.cancellable);
@@ -142,51 +147,11 @@ store_task_free (TrackerStoreTask *task)
 static gboolean
 watchdog_cb (gpointer user_data)
 {
-	TrackerStorePrivate *private = user_data;
-	GSList *running;
+	TrackerStoreTask *task = user_data;
 
-	private = user_data;
-	running = private->running_tasks;
+	g_cancellable_cancel (task->data.query.cancellable);
 
-	if (!running) {
-		private->watchdog_id = 0;
-		return FALSE;
-	}
-
-	while (running) {
-		TrackerStoreTask *task;
-		GCancellable *cancellable;
-
-		task = running->data;
-		running = running->next;
-		cancellable = task->data.query.cancellable;
-
-		if (cancellable && private->max_task_time &&
-		    g_timer_elapsed (task->data.query.timer, NULL) > private->max_task_time) {
-			g_cancellable_cancel (cancellable);
-		}
-	}
-
-	return TRUE;
-}
-
-static void
-ensure_running_tasks_watchdog (TrackerStorePrivate *private)
-{
-	if (private->watchdog_id == 0) {
-		private->watchdog_id = g_timeout_add_seconds (TRACKER_STORE_QUERY_WATCHDOG_TIMEOUT,
-		                                              watchdog_cb, private);
-	}
-}
-
-static void
-check_running_tasks_watchdog (TrackerStorePrivate *private)
-{
-	if (private->running_tasks == NULL &&
-	    private->watchdog_id != 0) {
-		g_source_remove (private->watchdog_id);
-		private->watchdog_id = 0;
-	}
+	return FALSE;
 }
 
 static void
@@ -214,11 +179,13 @@ sched (TrackerStorePrivate *private)
 		}
 
 		private->running_tasks = g_slist_prepend (private->running_tasks, task);
-		ensure_running_tasks_watchdog (private);
+
+		if (private->max_task_time) {
+			task->data.query.watchdog_id = g_timeout_add_seconds (private->max_task_time,
+			                                                      watchdog_cb, task);
+		}
+
 		private->n_queries_running++;
-
-		task->data.query.timer = g_timer_new ();
-
 		g_thread_pool_push (private->query_pool, task, NULL);
 	}
 
@@ -232,7 +199,6 @@ sched (TrackerStorePrivate *private)
 		}
 		if (task != NULL) {
 			private->update_running = TRUE;
-
 			g_thread_pool_push (private->update_pool, task, NULL);
 		}
 	}
@@ -260,9 +226,7 @@ task_finish_cb (gpointer data)
 			g_clear_error (&task->error);
 		}
 
-		task->data.query.cancellable = g_cancellable_new ();
 		private->running_tasks = g_slist_remove (private->running_tasks, task);
-		check_running_tasks_watchdog (private);
 		private->n_queries_running--;
 	} else if (task->type == TRACKER_STORE_TASK_TYPE_UPDATE) {
 		if (!task->error) {
@@ -329,6 +293,14 @@ task_finish_cb (gpointer data)
 
 	store_task_free (task);
 
+	if (private->n_queries_running == 0 &&
+	    !private->update_running &&
+	    private->active_callback)
+	{
+		private->active_callback (private->active_user_data);
+		private->active_callback = NULL;
+	}
+
 	sched (private);
 
 	return FALSE;
@@ -479,6 +451,7 @@ tracker_store_sparql_query (const gchar *sparql,
 	task = g_slice_new0 (TrackerStoreTask);
 	task->type = TRACKER_STORE_TASK_TYPE_QUERY;
 	task->data.query.query = g_strdup (sparql);
+	task->data.query.cancellable = g_cancellable_new ();
 	task->user_data = user_data;
 	task->callback.query.query_callback = callback;
 	task->callback.query.in_thread = in_thread;
@@ -686,13 +659,46 @@ tracker_store_unreg_batches (const gchar *client_id)
 	sched (private);
 }
 
+static gboolean
+active_cb_in_idle (gpointer user_data)
+{
+	SetActiveDelegate *data = user_data;
+
+	data->callback (data->user_data);
+	g_free (data);
+
+	return FALSE;
+}
+
 void
-tracker_store_set_active (gboolean active)
+tracker_store_set_active (gboolean       active,
+                          GDestroyNotify callback,
+                          gpointer       user_data)
 {
 	TrackerStorePrivate *private;
 
 	private = g_static_private_get (&private_key);
+
 	private->active = active;
 
-	sched (private);
+	if (active == FALSE &&
+	    private->n_queries_running == 0 &&
+	    !private->update_running &&
+	    callback)
+	{
+		SetActiveDelegate *data = g_new0 (SetActiveDelegate, 1);
+
+		data->callback = callback;
+		data->user_data = user_data;
+		g_idle_add (active_cb_in_idle, data);
+
+		private->active_callback = NULL;
+	} else {
+		private->active_callback = callback;
+		private->active_user_data = user_data;
+	}
+
+	if (active) {
+		sched (private);
+	}
 }
